summaryrefslogtreecommitdiffstats
path: root/karbon/core/vtext.cc
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/core/vtext.cc')
-rw-r--r--karbon/core/vtext.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/karbon/core/vtext.cc b/karbon/core/vtext.cc
index e98883553..4c7d3989b 100644
--- a/karbon/core/vtext.cc
+++ b/karbon/core/vtext.cc
@@ -473,7 +473,7 @@ VText::traceText()
bool foundCharmap = false;
// Try to choose tqunicode charmap
for( int charmap = 0; charmap < fontFace->num_charmaps; charmap++ )
{
if( fontFace->charmaps[charmap]->encoding == ft_encoding_unicode )
@@ -481,14 +481,14 @@ VText::traceText()
FT_Error error = FT_Set_Charmap( fontFace, fontFace->charmaps[charmap] );
if( error )
{
- kdDebug(38000) << "traceText(), unable to select tqunicode charmap." << endl;
+ kdDebug(38000) << "traceText(), unable to select unicode charmap." << endl;
continue;
}
foundCharmap = true;
}
}
// Choose first charmap if no tqunicode charmap was found
if( ! foundCharmap )
{
error = FT_Set_Charmap( fontFace, fontFace->charmaps[0] );
@@ -518,7 +518,7 @@ VText::traceText()
{
// get the glyph index for the current character
TQChar character = m_text.at( i );
- glyphIndex = FT_Get_Char_Index( fontFace, character.tqunicode() );
+ glyphIndex = FT_Get_Char_Index( fontFace, character.unicode() );
if( ! glyphIndex )
{
kdDebug(38000) << "traceText(), unable get index of char : " << character << endl;
@@ -473,7 +473,7 @@ VText::traceText()
bool foundCharmap = false;
- // Try to choose tqunicode charmap
+ // Try to choose unicode charmap
for( int charmap = 0; charmap < fontFace->num_charmaps; charmap++ )
{
@@ -481,14 +481,14 @@ VText::traceText()
}
}
- // Choose first charmap if no tqunicode charmap was found
+ // Choose first charmap if no unicode charmap was found
if( ! foundCharmap )
{